#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for running analysis of clustering, generating statistics on the clustering.

@author: mark
"""

import logging
import scipy.cluster.hierarchy as cluster

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

def calculate_max_inconsistency_stats(linkage_matrix, inconsistency_matrix, i):
    """Returns the maximum statistic for each non-singleton cluster and its descendents.
    """
    return cluster.maxRstat(linkage_matrix, inconsistency_matrix, i)

def calculate_max_dist(linkage_matrix):
    """This calculates the maximum distance between any non-singleton cluster.
    """
    return cluster.maxdists(linkage_matrix)

def calculate_inconsistency(linkage_matrix, d=2):
    """This calculates the inconsistency statistics on the linkage matrix
    """
    return cluster.inconsistent(linkage_matrix, d=d)

def calculate_cophenetic_distance(linkage_matrix, input_matrix):
    """This calculates the cophenet matrix and returns the cophenetic 
    """
    return cluster.cophenet(linkage_matrix, Y=input_matrix)
