#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for preparing the Similarity Matrices for clustering. This contains
methods to reads in a matrix from a file, and return the labels as well as a
triangular matrix ready for clustering.

@author: mark
"""

import logging
import scipy.spatial.distance as scidist
import solventmapcreator.io.similaritymatrixreader as similaritymatrixreader

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

def parse_similarity_matrix_file_condensed_matrix(filename):
    """This reads a file into a dictionary, then appends the condensed matrix
    to the dictionary.
    """
    similarity_matrix_info = parse_similarity_matrix_file(filename)
    append_condensed_matrix(similarity_matrix_info)
    return similarity_matrix_info

def append_condensed_matrix(similarity_matrix_info):
    """This appends a condensed matrix to the input dict.
    """
    similarity_matrix_info["condensed_matrix"] = convert_to_condensed_matrix(similarity_matrix_info["value_matrix"])

def convert_to_condensed_matrix(similarity_matrix):
    """This converts the matrix to a condensed matrix.
    """
    return scidist.squareform(similarity_matrix)

def parse_similarity_matrix_file(filename):
    """This reads a file in to a dictionary, containing the labels and the
    similarity matrix.
    """
    return similaritymatrixreader.parse_similarity_matrix_file(filename)
